@@ -7,7 +7,6 @@ def _get(inputDataFrame, plotConfigData):
 
     fig = _go.Figure()
 
-    print(plotConfigData)
     extra_options = {}
 
     # if we have cols and rows, we want to make independent
@@ -20,12 +19,14 @@ def _get(inputDataFrame, plotConfigData):
         makeIndepY = True
         del plotConfigData["params"]["indep_y"]
 
+    if "colorscale" in plotConfigData["params"]:
+        extra_options["colorscale"] = plotConfigData["params"]["colorscale"]
+
     if "range_color" in plotConfigData["params"]:
-        
+
         extra_options["zmin"] = plotConfigData["params"]["range_color"][0]
         extra_options["zmax"] = plotConfigData["params"]["range_color"][1]
         del plotConfigData["params"]["range_color"]
-    
 
     if "x" in plotConfigData["params"] and "y" in plotConfigData["params"] and "dimensions" in plotConfigData["params"]:
         # extrat params
@@ -127,14 +128,26 @@ def _get(inputDataFrame, plotConfigData):
                     col=colid,
                     coloraxis="coloraxis",
                     xaxis=None if makeIndepX else "x",
-                    yaxis=None if makeIndepY else "y",
-                    **extra_options
+                    yaxis=None if makeIndepY else "y"
                 )
                 colid = colid + 1
                 if colid > col_wrap:
                     rowid = rowid + 1
                     colid = 1
 
+            if "zmin" in extra_options:
+                fig.update_coloraxes(
+                    cmin=extra_options["zmin"]
+                )
+            if "zmax" in extra_options:
+                fig.update_coloraxes(
+                    cmax=extra_options["zmax"]
+                )
+            if "colorscale" in extra_options:
+                fig.update_coloraxes(
+                    colorscale=extra_options["colorscale"]
+                )                
+
         else:
             fig.add_heatmap(
                 x0=all_min[0], dx=1,
@@ -144,4 +157,4 @@ def _get(inputDataFrame, plotConfigData):
                 **extra_options
             )
 
-    return fig
\ No newline at end of file
+    return fig
